@@ -17,6 +17,10 @@
 #' @param summary function name to use to summarize the output to be a sinlge row (default is the mean).
 #' @param root root argument for \code{\link{edit_apsim}}
 #' @param verbose whether to print progress in percent and elapsed time.
+#' @param cores number of cores to use for parallel evaluation
+#' @param save whether to save intermediate results. By default they will be saved as a
+#' \sQuote{csv} file using the name of the apsim file. This will replace \sQuote{apsim} with \sQuote{csv}.
+#' It is also possible to provide the file name here (for example: \sQuote{Some_results.csv}).
 #' @param ... additional arguments (none used at the moment).
 #' @note The summary function is stored as an attribute of the data frame \sQuote{grid.sims}.
 #' @return object of class \sQuote{sens_apsim}, but really just a list with results from the evaluations.
@@ -36,6 +40,8 @@ sens_apsim <- function(file, src.dir = ".",
                        summary = c("mean", "max", "var", "sd", "none"),
                        root,
                        verbose = TRUE,
+                       cores = 1L,
+                       save,
                        ...){
   
   if(missing(file))
@@ -44,6 +50,11 @@ sens_apsim <- function(file, src.dir = ".",
   .check_apsim_name(file)
   .check_apsim_name(src.dir)
   
+  if(cores > 1L){
+    stop("This feature has not been implemented yet for Classic. 
+         Please submit an issue in github if you need it")    
+  }
+
   if(src.dir != ".") stop("At the moment it is not possible \n
                           to change the source directory.")
   
@@ -183,6 +194,24 @@ sens_apsim <- function(file, src.dir = ".",
     
     col.sim <- rbind(col.sim, sim.sd)
     
+    if(save != FALSE){
+      if(isTRUE(save)){
+        save.file.name <- paste0(tools::file_path_sans_ext(file), ".csv")
+        utils::write.csv(col.sim, 
+                         file = save.file.name,
+                         row.names = FALSE)
+      }else{
+        if(!is.character(save))
+          stop("'save' argument should be a character", call. = FALSE)
+        if(tools::file_ext(save) != "csv")
+          stop("'save' only accepts 'csv' as an extension", call. = FALSE)
+        save.file.name <- save
+        utils::write.csv(col.sim, 
+                         file = save.file.name,
+                         row.names = FALSE)
+      }
+    }
+    
     if(verbose){
       nrow.grid <- nrow(grid)
       old.prev.div <- 0
@@ -204,6 +233,9 @@ sens_apsim <- function(file, src.dir = ".",
     }
   }
   
+  if(verbose && !isFALSE(save))
+    cat("Saved results as:", save.file.name, "\n")
+  
   if(summary != "none"){
     cdat <- cbind(grid, col.sim)  
   }else{
